import { NgModule, Optional, SkipSelf, Pipe } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { MatButtonModule } from '@angular/material/button';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { MatDialogModule } from '@angular/material/dialog';
import { MatInputModule } from '@angular/material/input';
import { MatProgressBarModule } from '@angular/material/progress-bar';
import { MatProgressSpinnerModule } from '@angular/material/progress-spinner';
import { MatSelectModule } from '@angular/material/select';
import { MatTooltipModule } from '@angular/material/tooltip';
import { DialogModule as DialogModule$1 } from '@dialog/dialog.module';
import { AuthenticationServiceConfig } from '@authentication/model/authentication.service.config';
export * from '@authentication/model/authentication.service.config';
export { DialogModule, EmailModule, EmployeeModule, SafeUrlPipe, SharePointModule, UploadModule, UriSchemePipe, UrlModule } from '@authentication/model/authentication.service.config';
import { AuthenticationService } from '@authentication/services/authentication.service';
export * from '@authentication/services/authentication.service';
import { LoginComponent } from '@authentication/components/login/login.component';
export * from '@authentication/components/login/login.component';
import { LoginFormComponent } from '@authentication/components/login-form/login-form.component';
export * from '@authentication/components/login-form/login-form.component';
export * from '@authentication/model/authentication-token';
import { DialogComponent } from '@dialog/components/_dialog/dialog.component';
import { ConfirmationDialogComponent } from '@dialog/components/confirmation-dialog/confirmation-dialog.component';
export * from '@dialog/components/confirmation-dialog/confirmation-dialog.component';
import { InputDialogComponent } from '@dialog/components/input-dialog/input-dialog.component';
export * from '@dialog/components/input-dialog/input-dialog.component';
import { MessageDialogComponent } from '@dialog/components/message-dialog/message-dialog.component';
export * from '@dialog/components/message-dialog/message-dialog.component';
export * from '@dialog/model/confirmation-dialog-mode.enum';
import { EmailServiceConfig } from '@email/model/email.service.config';
export * from '@email/model/email.service.config';
import { EmailService } from '@email/services/email.service';
export * from '@email/services/email.service';
export * from '@email/model/email';
import { EmployeeServiceConfig } from '@employee/model/employee.service.config';
export * from '@employee/model/employee.service.config';
import { EmployeeService } from '@employee/services/employee.service';
export * from '@employee/services/employee.service';
import { DepartmentsPipe } from '@employee/pipes/departments.pipe';
export * from '@employee/pipes/departments.pipe';
import { EmployeeByDnPipe } from '@employee/pipes/employee-by-dn.pipe';
export * from '@employee/pipes/employee-by-dn.pipe';
import { EmployeePhotoUrlPipe } from '@employee/pipes/employee-photo-url.pipe';
export * from '@employee/pipes/employee-photo-url.pipe';
import { EmployeesWithPropertyValuePipe } from '@employee/pipes/employees-with-property-value.pipe';
export * from '@employee/pipes/employees-with-property-value.pipe';
import { FilterEmployeesPipe } from '@employee/pipes/filter-employees.pipe';
export * from '@employee/pipes/filter-employees.pipe';
import { IsMemberOfPipe } from '@employee/pipes/is-member-of.pipe';
export * from '@employee/pipes/is-member-of.pipe';
import { SortEmployeesPipe } from '@employee/pipes/sort-employees.pipe';
export * from '@employee/pipes/sort-employees.pipe';
export * from '@employee/model/employee';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { HttpClientModule } from '@angular/common/http';
import { MatListModule } from '@angular/material/list';
import { UploadServiceConfig } from '@upload/model/upload.service.config';
export * from '@upload/model/upload.service.config';
import { UploadService } from '@upload/services/upload.service';
export * from '@upload/services/upload.service';
import { UploadDialogComponent } from '@upload/components/upload-dialog/upload-dialog.component';
export * from '@upload/components/upload-dialog/upload-dialog.component';
import { UploadComponent } from '@upload/components/upload/upload.component';
export * from '@upload/components/upload/upload.component';
export * from '@upload/model/database-file-info';
export * from '@upload/model/file-upload-request';
export * from '@upload/model/filesystem-file-info';
import { SharePointServiceConfig } from '@sharepoint/model/sharepoint.service.config';
export * from '@sharepoint/model/sharepoint.service.config';
import { SharePointService } from '@sharepoint/services/sharepoint.service';
export * from '@sharepoint/services/sharepoint.service';
import { SharePointPhotoUrlPipe } from '@sharepoint/pipes/sharepoint-photo-url.pipe';
export * from '@sharepoint/pipes/sharepoint-photo-url.pipe';
import { SharePointUrlPipe } from '@sharepoint/pipes/sharepoint-url.pipe';
export * from '@sharepoint/pipes/sharepoint-url.pipe';
export * from '@sharepoint/model/sharepoint-calendar-event';
export * from '@sharepoint/model/sharepoint-customer-visit';
export * from '@sharepoint/model/sharepoint-employee-picture';
export * from '@sharepoint/model/sharepoint-list';
export * from '@sharepoint/model/sharepoint-list-item';
export * from '@sharepoint/model/sharepoint-person';
export * from '@sharepoint/model/sharepoint-picture';

//#region Imports
//#endregion
class AuthenticationModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('AuthenticationModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(authenticationConfig) {
        return {
            ngModule: AuthenticationModule,
            providers: [
                AuthenticationService,
                { provide: AuthenticationServiceConfig, useValue: authenticationConfig }
            ]
        };
    }
}
AuthenticationModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    MatButtonModule,
                    MatCheckboxModule,
                    MatDialogModule,
                    MatInputModule,
                    MatProgressBarModule,
                    MatProgressSpinnerModule,
                    MatTooltipModule,
                    MatSelectModule,
                    DialogModule$1
                ],
                declarations: [
                    LoginComponent,
                    LoginFormComponent
                ],
                exports: [
                    LoginComponent,
                    LoginFormComponent
                ],
                providers: [],
                entryComponents: [
                    LoginFormComponent
                ]
            },] }
];
AuthenticationModule.ctorParameters = () => [
    { type: AuthenticationModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
];

//#region Imports
//#endregion
class DialogModule {
}
DialogModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    MatButtonModule,
                    MatCheckboxModule,
                    MatInputModule,
                    MatDialogModule
                ],
                declarations: [
                    DialogComponent,
                    ConfirmationDialogComponent,
                    InputDialogComponent,
                    MessageDialogComponent
                ],
                exports: [
                    ConfirmationDialogComponent,
                    InputDialogComponent,
                    MessageDialogComponent
                ],
                entryComponents: [
                    ConfirmationDialogComponent,
                    InputDialogComponent,
                    MessageDialogComponent
                ]
            },] }
];

//#region Imports
//#endregion
class EmailModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('EmailModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(emailConfig) {
        return {
            ngModule: EmailModule,
            providers: [
                EmailService,
                { provide: EmailServiceConfig, useValue: emailConfig }
            ]
        };
    }
}
EmailModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [],
                exports: []
            },] }
];
EmailModule.ctorParameters = () => [
    { type: EmailModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
];

//#region Imports
//#endregion
class EmployeeModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('EmployeeModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(employeeConfig) {
        return {
            ngModule: EmployeeModule,
            providers: [
                EmployeeService,
                { provide: EmployeeServiceConfig, useValue: employeeConfig }
            ]
        };
    }
}
EmployeeModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [
                    DepartmentsPipe,
                    EmployeeByDnPipe,
                    EmployeesWithPropertyValuePipe,
                    FilterEmployeesPipe,
                    IsMemberOfPipe,
                    EmployeePhotoUrlPipe,
                    SortEmployeesPipe
                ],
                exports: [
                    DepartmentsPipe,
                    EmployeeByDnPipe,
                    EmployeesWithPropertyValuePipe,
                    FilterEmployeesPipe,
                    IsMemberOfPipe,
                    EmployeePhotoUrlPipe,
                    SortEmployeesPipe
                ]
            },] }
];
EmployeeModule.ctorParameters = () => [
    { type: EmployeeModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
];

//#region Imports
//#endregion
class UploadModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('UploadModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(uploadConfig) {
        return {
            ngModule: UploadModule,
            providers: [
                UploadService,
                { provide: UploadServiceConfig, useValue: uploadConfig }
            ]
        };
    }
}
UploadModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    BrowserAnimationsModule,
                    HttpClientModule,
                    MatButtonModule,
                    MatDialogModule,
                    MatListModule,
                    MatProgressBarModule
                ],
                declarations: [
                    UploadComponent,
                    UploadDialogComponent
                ],
                exports: [
                    UploadComponent,
                    UploadDialogComponent
                ],
                entryComponents: [
                    UploadDialogComponent
                ]
            },] }
];
UploadModule.ctorParameters = () => [
    { type: UploadModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
];

//#region Imports
//#endregion
class SharePointModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('SharePointModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(sharePointConfig) {
        return {
            ngModule: SharePointModule,
            providers: [
                SharePointService,
                { provide: SharePointServiceConfig, useValue: sharePointConfig }
            ]
        };
    }
}
SharePointModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    SharePointPhotoUrlPipe,
                    SharePointUrlPipe
                ],
                exports: [
                    SharePointPhotoUrlPipe,
                    SharePointUrlPipe
                ]
            },] }
];
SharePointModule.ctorParameters = () => [
    { type: SharePointModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
];

class SafeUrlPipe {
    transform(value, ...args) {
        return null;
    }
}
SafeUrlPipe.decorators = [
    { type: Pipe, args: [{
                name: 'safeUrl'
            },] }
];

class UriSchemePipe {
    transform(value, ...args) {
        return null;
    }
}
UriSchemePipe.decorators = [
    { type: Pipe, args: [{
                name: 'uriScheme'
            },] }
];

//#region Imports
//#endregion
class UrlModule {
}
UrlModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [
                    SafeUrlPipe,
                    UriSchemePipe
                ],
                exports: [
                    SafeUrlPipe,
                    UriSchemePipe
                ]
            },] }
];

/*
 * Public API Surface of ngx-lib
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AuthenticationModule };
//# sourceMappingURL=cleavelandprice-ngx-lib.js.map
